@@ -16,6 +16,9 @@ sub run {
   # Read config
   my $config = $api->read_config;
   
+  # Copy static files to public
+  $api->copy_static_files_to_public;
+
   # Get files in templates directory
   my $files = $api->get_templates_files;
   
